Learn R Programming

rscorecard (version 0.2.4)

sc_dict: Search data dictionary.

Description

This function is used to search the College Scorecard data dictionary.

Usage

sc_dict(search_string, search_col = c("description", "varname",
  "dev_friendly_name", "dev_category", "label"), ignore_case = TRUE,
  limit = 10, confirm = FALSE)

Arguments

search_string
Character string for search. Can use regular expression for search. Must escape special characters, . | ( ) [ { ^ $ * + ?, with a doublebackslash \\.
search_col
Column to search. The default column is the "description" column. Other options include: "varname", "dev_friendly_name", "dev_category", "label".
ignore_case
Search is case insensitive by default. Change to FALSE to restrict search to exact case matches.
limit
Only the first 10 dictionary items are returned by default. Increase to return more values. Set to Inf to return all items matched in search'
confirm
Use to confirm status of variable name in dictionary. Returns TRUE or FALSE.

Examples

Run this code
sc_dict('state')
sc_dict('^st', search_col = 'varname') # variable names starting with 'st'
sc_dict('.', limit = Inf) # return full dictionary (not recommended)

Run the code above in your browser using DataLab