This function is used to select the year of the data.
Usage
sc_year(sccall, year)
Arguments
sccall
Current list of parameters carried forward from prior
functions in the chain (ignore)
year
Four-digit year (default is 2013)
Important notes
Not all variables have a year option.
At this time, only one year at a time is allowed.
The year selected is not necessarily the year the data were produced.
It may be the year the data were collected. For data collected over split
years (fall to spring), it is likely the year represents the fall data (e.g.,2011 for 2011/2012 data).
Be sure to check with the College Scorecard
https://collegescorecard.ed.gov/assets/FullDataDocumentation.pdf{data
documentation report} when choosing the year.