Learn R Programming

rscorecard (version 0.26.0)

sc_zip: Subset results to those within specified area around zip code.

Description

Subset results to those within specified area around zip code.

Usage

sc_zip(sccall, zip, distance = 25, km = FALSE)

Arguments

sccall

Current list of parameters carried forward from prior functions in the chain (ignore)

zip

A 5-digit zipcode

distance

An integer distance in miles or kilometers

km

A boolean value set to TRUE if distance should be in kilometers (default is FALSE for miles)

Examples

Run this code
if (FALSE) {
sc_zip(37203)
sc_zip(37203, 50)
sc_zip(37203, 50, km = TRUE)
sc_zip('02111')              # 1. Using string
sc_zip(02111)                # 2. Dropped leading zero will be added
sc_zip(2111)                 # 3. Will become '02111' (not recommended)
}

Run the code above in your browser using DataLab